gambit: Computations on finite, noncooperative games
====================================================

Description
-----------

Gambit is a set of software tools for doing computation on finite,
noncooperative games. The Gambit Project was founded in the mid-1980s by
Richard McKelvey at the California Institute of Technology.

License
-------

GPL v2+


Upstream Contact
----------------

-  Website: http://www.gambit-project.org/
-  Mailing List: http://sourceforge.net/p/gambit/mailman/gambit-devel/

Dependencies
------------

-  python
-  cython
-  setuptools
-  IPython
-  scipy
